@@ -1,5 +1,23 @@
-# Copyright (c) 2014 Marcel Greter,
-# All Rights Reserved. -*- cperl -*-
+# Copyright (c) 2013 David Caldwell.
+# Copyright (c) 2014 Marcel Greter.
+#
+# Permission is hereby granted, free of charge, to any person obtaining a copy
+# of this software and associated documentation files (the "Software"), to deal
+# in the Software without restriction, including without limitation the rights
+# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+# copies of the Software, and to permit persons to whom the Software is
+# furnished to do so, subject to the following conditions:
+#
+# The above copyright notice and this permission notice shall be included in
+# all copies or substantial portions of the Software.
+#
+# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
+# THE SOFTWARE.
 
 use strict;
 use warnings;
@@ -7,7 +25,7 @@ use CSS::Sass;
 
 ################################################################################
 package CSS::Sass::Watchdog;
-our $VERSION = "v3.2.2";
+our $VERSION = "3.3.0";
 ################################################################################
 
 use Exporter 'import'; # gives you Exporter's import() method directly
@@ -236,14 +254,14 @@ END
 	# check if we actually are the parent
 	if ($parent_pid && $parent_pid == $$)
 	{
-		print "parent is terminating\n";
+		# print "parent is terminating\n";
 		# make sure our child is terminated
 		kill 'TERM', $child_pid if $child_pid;
 	}
 	# check if we actually are the parent
 	elsif ($parent_pid && $parent_pid != $$)
 	{
-		print "file watcher was terminated\n";
+		# print "file watcher was terminated\n";
 	}
 }
 
